@@ -368,30 +368,30 @@ static int create_default_script(char *file_name)
 	if(add_command(fd, (char *)CMD_END_CMD,              0)) return fclose(fd);
 
 	// RIG HRDWR PTT
-	if(add_command(fd, (char *)CMD_HRDWR_PTT,                0)) return fclose(fd);
-	if(add_command(fd, (char *)CMD_HPPT_PTT_RT,              (bool)   btnPTTrightchannel->value(), 1)) return fclose(fd);
-	if(add_command(fd, (char *)CMD_HPTT_SP2,                 (bool)   btnTTYptt->value(),          1)) return fclose(fd);
-	if(add_command(fd, (char *)CMD_HPTT_SP2_PATH,            (char *) inpTTYdev->value(),          1)) return fclose(fd);
-	if(add_command(fd, (char *)CMD_HPTT_SP2_RTS,             (bool)   btnRTSptt->value(),          1)) return fclose(fd);
-	if(add_command(fd, (char *)CMD_HPTT_SP2_RTS_V,           (bool)   btnRTSplusV->value(),        1)) return fclose(fd);
-	if(add_command(fd, (char *)CMD_HPTT_SP2_DTR,             (bool)   btnDTRptt->value(),          1)) return fclose(fd);
-	if(add_command(fd, (char *)CMD_HPTT_SP2_DTR_V,           (bool)   btnDTRplusV->value(),        1)) return fclose(fd);
-	if(add_command(fd, (char *)CMD_HPTT_PARALLEL,            (bool)   btnUsePPortPTT->value(),     1)) return fclose(fd);
+	if(add_command(fd, (char *) "# " CMD_HRDWR_PTT,                0)) return fclose(fd);
+	if(add_command(fd, (char *) "# " CMD_HPPT_PTT_RT,              (bool)   btnPTTrightchannel->value(), 1)) return fclose(fd);
+	if(add_command(fd, (char *) "# " CMD_HPTT_SP2,                 (bool)   btnTTYptt->value(),          1)) return fclose(fd);
+	if(add_command(fd, (char *) "# " CMD_HPTT_SP2_PATH,            (char *) inpTTYdev->value(),          1)) return fclose(fd);
+	if(add_command(fd, (char *) "# " CMD_HPTT_SP2_RTS,             (bool)   btnRTSptt->value(),          1)) return fclose(fd);
+	if(add_command(fd, (char *) "# " CMD_HPTT_SP2_RTS_V,           (bool)   btnRTSplusV->value(),        1)) return fclose(fd);
+	if(add_command(fd, (char *) "# " CMD_HPTT_SP2_DTR,             (bool)   btnDTRptt->value(),          1)) return fclose(fd);
+	if(add_command(fd, (char *) "# " CMD_HPTT_SP2_DTR_V,           (bool)   btnDTRplusV->value(),        1)) return fclose(fd);
+	if(add_command(fd, (char *) "# " CMD_HPTT_PARALLEL,            (bool)   btnUsePPortPTT->value(),     1)) return fclose(fd);
 #if HAVE_UHROUTER
-	if(add_command(fd, (char *)CMD_HPTT_UHROUTER,            (bool)   btnUseUHrouterPTT->value(),  1)) return fclose(fd);
+	if(add_command(fd, (char *) "# " CMD_HPTT_UHROUTER,            (bool)   btnUseUHrouterPTT->value(),  1)) return fclose(fd);
 #endif
-	if(add_command(fd, (char *)CMD_HPTT_SP2_START_DELAY,     (int)    cntPTT_on_delay->value(),    1)) return fclose(fd);
-	if(add_command(fd, (char *)CMD_HPTT_SP2_END_DELAY,       (int)    cntPTT_off_delay->value(),   1)) return fclose(fd);
-	if(add_command(fd, (char *)CMD_HPTT_SP2_INITIALIZE,      1)) return fclose(fd);
-	if(add_command(fd, (char *)CMD_END_CMD,                  0)) return fclose(fd);
+	if(add_command(fd, (char *) "# " CMD_HPTT_SP2_START_DELAY,     (int)    cntPTT_on_delay->value(),    1)) return fclose(fd);
+	if(add_command(fd, (char *) "# " CMD_HPTT_SP2_END_DELAY,       (int)    cntPTT_off_delay->value(),   1)) return fclose(fd);
+	if(add_command(fd, (char *) "# " CMD_HPTT_SP2_INITIALIZE,      1)) return fclose(fd);
+	if(add_command(fd, (char *) "# " CMD_END_CMD,                  0)) return fclose(fd);
 
 	// Cmedia PTT
-	if(add_command(fd, (char *)CMD_CMEDIA_PTT,                0)) return fclose(fd);
-	if(add_command(fd, (char *)CMD_USE_CMEDIA_PTT,           (bool)   btn_use_cmedia_PTT->value(), 1)) return fclose(fd);
-	if(add_command(fd, (char *)CMD_CMEDIA_DEV,               (char *) progdefaults.cmedia_device.c_str(), 1)) return fclose(fd);
-	if(add_command(fd, (char *)CMD_CMEDIA_GPIO_LINE,         (char *) progdefaults.cmedia_gpio_line.c_str(), 1)) return fclose(fd);
-	if(add_command(fd, (char *)CMD_END_CMD,                  0)) return fclose(fd);
-
+	if(add_command(fd, (char *) "# " CMD_CMEDIA_PTT,                0)) return fclose(fd);
+	if(add_command(fd, (char *) "# " CMD_USE_CMEDIA_PTT,           (bool)   btn_use_cmedia_PTT->value(), 1)) return fclose(fd);
+	if(add_command(fd, (char *) "# " CMD_CMEDIA_DEV,               (char *) progdefaults.cmedia_device.c_str(), 1)) return fclose(fd);
+	if(add_command(fd, (char *) "# " CMD_CMEDIA_GPIO_LINE,         (char *) progdefaults.cmedia_gpio_line.c_str(), 1)) return fclose(fd);
+	if(add_command(fd, (char *) "# " CMD_END_CMD,                  0)) return fclose(fd);
+ 
 	// RIG CAT
 	if(add_command(fd, (char *)CMD_RIGCAT,                   0)) return fclose(fd);
 	if(add_command(fd, (char *)CMD_RIGCAT_STATE,             (bool)   chkUSERIGCAT->value(),               1)) return fclose(fd);
@@ -498,6 +498,7 @@ static int create_default_script(char *file_name)
 	if(add_command(fd, (char *)CMD_ID_RSID_SQL_OPEN,      (int)    val_RSIDsquelch->value(),      2)) return fclose(fd);
 	if(add_command(fd, (char *)CMD_ID_RSID_PRETONE,       (double) val_pretone->value(),          2)) return fclose(fd);
 	if(add_command(fd, (char *)CMD_ID_RSID_END_XMT_ID,    (bool)   btn_post_rsid->value(),        2)) return fclose(fd);
+	if(add_command(fd, (char *)CMD_ID_RSID_MIN_BW,        (int)    val_rsid_min_bw->value(),      2)) return fclose(fd);	
 	if(add_command(fd, (char *)CMD_END_CMD,               1)) return fclose(fd);
 	if(add_command(fd, (char *)CMD_ID_VIDEO,              1)) return fclose(fd);
 	if(add_command(fd, (char *)CMD_ID_VIDEO_TX_ID_MODE,   (bool)   btnsendid->value(),            2)) return fclose(fd);
