@@ -157,13 +157,11 @@ const struct mode_info_t mode_info[NUM_MODES] = {
 {MODE_8PSK1000F,&_8psk1000f_modem,"8PSK1000F","8PSK-1000F","8PSK1000F","8PSK1000F","PSK","","8PSK1000F", ARQ_IO | KISS_IO },
 {MODE_8PSK1200F,&_8psk1200f_modem,"8PSK1200F","8PSK-1200F","8PSK1200F","8PSK1200F","PSK","","8PSK1200F", ARQ_IO | KISS_IO },
 
-/* Commented out pending development work by KL4YFD
 {MODE_OFDM_500F,&ofdm_500f_modem,"OFDM500F","OFDM-500F","OFDM500F","OFDM500F","OFDM","","OFDM500F", ARQ_IO | KISS_IO },
 {MODE_OFDM_750F,&ofdm_750f_modem,"OFDM750F","OFDM-750F","OFDM750F","OFDM750F","OFDM","","OFDM750F", ARQ_IO | KISS_IO },
 //{MODE_OFDM_2000F,&ofdm_2000f_modem,"OFDM2000F","OFDM-2000F","OFDM2000F","OFDM2000F","OFDM","","OFDM2000F", ARQ_IO | KISS_IO },
 //{MODE_OFDM_2000,&ofdm_2000_modem,"OFDM2000","OFDM-2000","OFDM2000","OFDM2000","OFDM","","OFDM2000", ARQ_IO | KISS_IO },
 {MODE_OFDM_3500,&ofdm_3500_modem,"OFDM3500","OFDM-3500","OFDM3500","OFDM3500","OFDM","","OFDM3500", ARQ_IO | KISS_IO },
-*/
 
 {MODE_OLIVIA,&olivia_modem,"OLIVIA","OLIVIA","OLIVIA","OLIVIA","OLIVIA","","OL", DISABLED_IO },
 
@@ -305,20 +303,24 @@ std::ostream& operator<<(std::ostream& s, const qrg_mode_t& m)
 
 std::istream& operator>>(std::istream& s, qrg_mode_t& m)
 {
-	std::string sMode;
+	std::string sMode = "";
 	char temp[255];
-	int mnbr;
-	s >> m.rfcarrier >> m.rmode >> m.carrier >> sMode;
+	int mnbr = 0;
 
+   memset(temp, 0, sizeof(temp));
+   
+   s >> m.rfcarrier >> m.rmode >> m.carrier >> sMode;
 	s.getline(temp, 255);
 	m.usage = temp;
 	while (m.usage[0] == ' ') m.usage.erase(0,1);
 
+// This causes incorrect assignment when modem name starts with a number (ex:8PSK)
 // handle case for reading older type of specification std::string
-	if (sscanf(sMode.c_str(), "%d",&mnbr)) {
-		m.mode = mnbr;
-		return s;
-	}
+// if (sscanf(sMode.c_str(), "%d",&mnbr)) {
+// 	m.mode = mnbr;
+// 	return s;
+// }
+
 	m.mode = MODE_PSK31;
 	for (mnbr = MODE_CW; mnbr < NUM_MODES; mnbr++)
 		if (sMode == mode_info[mnbr].sname) {
