@@ -62,8 +62,11 @@ protected:
 	int		samplerate;
 	bool	reverse;
 	int		sigsearch;
+
 	bool	sig_start;
 	bool	sig_stop;
+	int		sig_smpl;
+	int		symlen;
 
 	double	bandwidth;
 	double	freqerr;
@@ -420,7 +423,13 @@ extern modem *psk500r_c3_modem;
 extern modem *psk500r_c4_modem;
 
 extern modem *rtty_modem;
-//extern modem *pkt_modem;
+
+extern modem *scampfsk_modem;
+extern modem *scampook_modem;
+extern modem *scfskfst_modem;
+extern modem *scfskslw_modem;
+extern modem *scookslw_modem;
+extern modem *scfskvsl_modem;
 
 extern modem *olivia_modem;
 extern modem *olivia_4_125_modem;
@@ -479,6 +488,7 @@ extern modem *thor11_modem;
 extern modem *thor16_modem;
 extern modem *thor22_modem;
 
+extern modem *thor25_modem;
 extern modem *thor32_modem;
 extern modem *thor44_modem;
 extern modem *thor56_modem;
