@@ -3,6 +3,10 @@
 #ifndef PLAY_PA_H
 #define PLAY_PA_H
 
+#include "config.h"
+
+#if USE_PORTAUDIO
+
 #include <portaudio.h>
 
 #include <stdio.h>
@@ -132,3 +136,5 @@ void open_alert_port(c_portaudio *cpa);
 void close_alert_port(c_portaudio *cpa);
 
 #endif
+
+#endif
