@@ -94,6 +94,7 @@ struct status {
 	bool	afconoff;
 	bool	sqlonoff;
 	bool	reverse;
+	bool	tx_lock;
 	double	txlevel;
 	int		scopeX;
 	int		scopeY;
@@ -271,6 +272,9 @@ struct status {
 
 	bool	useCW_KEYLINE;
 
+// THOR debug state
+	bool	thordebug;
+
 //----------------------------------------------------------------------
 // FMT saved controls
 	double	FMT_ref_freq;
