@@ -29,8 +29,6 @@
 
 #include "date.h"
 
-using namespace std;
-
 const int Date::mdays[] = 
   { 0, 31, 28, 31, 30,  31,  30,  31,  31,  30,  31,  30, 31 };
 
@@ -290,7 +288,7 @@ char *Date::szDate ()
 
 // operator functions
 
-ostream &operator<<( ostream &output, Date &d )
+std::ostream &operator<<( std::ostream &output, Date &d )
 {
   output << d.szDate ();
   return output;
