@@ -125,6 +125,8 @@ extern Fl_Scroll       *wefax_pic_rx_scroll;
 
 #include "cmedia.h"
 
+#include "scripts.h"
+
 #if BENCHMARK_MODE
 	#include "benchmark.h"
 #endif
@@ -180,6 +182,8 @@ string FLMSG_ICS_dir = "";
 string FLMSG_ICS_msg_dir = "";
 string FLMSG_ICS_tmp_dir = "";
 
+string RUN_SCRIPT = "";
+
 string PskMailFile;
 string ArqFilename;
 string xmlfname;
@@ -782,6 +786,12 @@ void delayed_startup(void *)
 	reset_audio_alerts();
 #endif
 
+	if (!RUN_SCRIPT.empty()) {
+		Fl::lock();
+		script_execute(RUN_SCRIPT.c_str(), false);
+		Fl::unlock();
+	}
+
 }
 
 std::string pname = "";
@@ -1240,6 +1250,9 @@ int main (int argc, char *argv[])
 		KmlServer::GetInstance()->Reset();
 	}
 
+	wf->setcolors();
+	setColorButtons();
+
 // OS X will prevent the main window from being resized if we change its
 // size *after* it has been shown. With some X11 window managers, OTOH,
 // the main window will not be restored at its exact saved position if
@@ -1418,6 +1431,11 @@ void generate_option_help(void) {
 		 << "  --xmlrpc-list\n"
 		 << "    List all available methods\n\n"
 
+		 << "  --script FILENAME\n"
+		 << "    Execute the script file FILENAME\n"
+		 << "    where FILENAME is fully qualified pathname to the\n"
+		 << "    desired script file\n\n"
+
 #if BENCHMARK_MODE
 		 << "  --benchmark-modem ID\n"
 		 << "    Specify the modem\n"
@@ -1551,6 +1569,8 @@ int parse_args(int argc, char **argv, int& idx)
 		   OPT_NBEMS_DIR,
 		   OPT_AUTOSEND_DIR,
 
+		   OPT_SCRIPT,
+
 		   OPT_CONFIG_XMLRPC_ADDRESS, OPT_CONFIG_XMLRPC_PORT,
 		   OPT_CONFIG_XMLRPC_ALLOW, OPT_CONFIG_XMLRPC_DENY, OPT_CONFIG_XMLRPC_LIST,
 		   OPT_CONFIG_KISS_ADDRESS, OPT_CONFIG_KISS_PORT_IO, OPT_CONFIG_KISS_PORT_O,
@@ -1616,6 +1636,8 @@ int parse_args(int argc, char **argv, int& idx)
 
 		{ "font",	   1, 0, OPT_FONT },
 
+		{ "script",  1, 0, OPT_SCRIPT },
+
 		{ "wfall-height",  1, 0, OPT_WFALL_HEIGHT },
 		{ "window-width",  1, 0, OPT_WINDOW_WIDTH },
 		{ "window-height", 1, 0, OPT_WINDOW_HEIGHT },
@@ -1703,6 +1725,10 @@ int parse_args(int argc, char **argv, int& idx)
 			FLMSG_WRAP_auto_dir = optarg;
 			break;
 
+		case OPT_SCRIPT:
+			RUN_SCRIPT = optarg;
+			break;
+
 		case OPT_ENABLE_IO_PORT:
 			if(optarg) {
 				switch(atoi(optarg)) {
