@@ -82,8 +82,8 @@ static char USTTY_figures[32] = {
 static char ITA2_figures[32] = {
 	'\0',	'3',	'\n',	'-',	' ',	'\'',	'8',	'7',
 	'\r',	' ',	'4',	'\a',	',',	'!',	':',	'(',
-	'5',	'"',	')',	'2',	'#',	'6',	'0',	'1',
-	'9',	'?',	'&',	' ',	'.',	'/',	';',	' '
+	'5',	'+',	')',	'2',	'#',	'6',	'0',	'1',
+	'9',	'?',	'&',	' ',	'.',	'/',	'=',	' '
 };
 
 static char *figures;
@@ -1133,7 +1133,7 @@ int rtty::rtty_sleep (double sleep_time)
 	timeBeginPeriod(1);
 #endif
 //	while (1) {
-		rval = nanosleep (&tv, &tv);
+		rval = nano_sleep (&tv, &tv);
 		if (errno == EINTR) {
 //			continue
 std::cout << "EINTR error in rtty_sleep" << std::endl;
