@@ -2,11 +2,16 @@
 //
 // play various canned play_sounds or wav file using port audio interface
 
+#include "config.h"
+
 #include "audio_alert.h"
+
 #include "configuration.h"
 #include "confdialog.h"
 #include "rxmon.h"
 
+#if USE_PORTAUDIO
+
 #define SC_RATE 8000
 #define PHONERING 15000
 
@@ -169,10 +174,11 @@ void Caudio_alert::alert(std::string s)
 	else file(s);
 }
 
-void Caudio_alert::monitor(double *buffer, int len, int _sr)
+void Caudio_alert::monitor(double *buffer, int len, int _sr, double amp)
 {
-	if (progdefaults.mon_xcvr_audio)
-		sc_audio->mon_write(buffer, len, _sr);
+	double nubuff[len];
+	for (int i = 0; i < len; i++) nubuff[i] = buffer[i] * amp;
+	sc_audio->mon_write(nubuff, len, _sr);
 }
 
 Caudio_alert::Caudio_alert()
@@ -236,3 +242,13 @@ void reset_audio_alerts()
 		LOG_INFO("Closed audio alert device %s", progdefaults.AlertDevice.c_str());
 	}
 }
+
+#else
+
+Caudio_alert *audio_alert;
+
+void reset_audio_alerts() {}
+
+void center_rxfilt_at_track() {}
+
+#endif
