@@ -500,8 +500,8 @@ void status::saveLastState()
 	Fl_Preferences spref(HomeDir.c_str(), "w1hkj.org", PACKAGE_TARNAME);
 #else
 	Fl_Preferences spref(
-		std::string(HomeDir).c_str(),
-		"w1hkj.com",
+		HomeDir.c_str(),
+		"w1hkj.org",
 		PACKAGE_TARNAME,
 		Fl_Preferences::C_LOCALE);
 #endif
@@ -788,8 +788,8 @@ void status::loadLastState()
 	Fl_Preferences spref(HomeDir.c_str(), "w1hkj.org", PACKAGE_TARNAME);
 #else
 	Fl_Preferences spref(
-		std::string(HomeDir).c_str(),
-		"w1hkj.com",
+		HomeDir.c_str(),
+		"w1hkj.org",
 		PACKAGE_TARNAME,
 		Fl_Preferences::C_LOCALE);
 #endif
