@@ -336,12 +336,10 @@ void trx_trx_receive_loop()
 			QRUNNER_DROP(true);
 			if (progdefaults.rsid)
 				ReedSolomon->receive(fbuf, numread);
-/* Commented out pending development work by KL4YFD
 			else if (active_modem->get_mode() == MODE_OFDM_500F 
 					 || active_modem->get_mode() == MODE_OFDM_750F)
 //					 || active_modem->get_mode() == MODE_OFDM_2000F)
 				ReedSolomon->receive(fbuf, numread); // OFDM modes use RSID as AFC mechanism. Force RxRSID.
-*/
 			active_modem->HistoryON(true);
 			active_modem->rx_process(hsbuff, numread);
 			QRUNNER_DROP(false);
@@ -368,12 +366,10 @@ void trx_trx_receive_loop()
 
 				if (progdefaults.rsid)
 					ReedSolomon->receive(fbuf, numread);
-/* Commented out pending development work by KL4YFD
 				else if (active_modem->get_mode() == MODE_OFDM_500F 
 						 || active_modem->get_mode() == MODE_OFDM_750F)
 //						 || active_modem->get_mode() == MODE_OFDM_2000F)
 					ReedSolomon->receive(fbuf, numread);  // OFDM modes use RSID as AFC mechanism. Force RxRSID.
-*/
 				dtmf->receive(fbuf, numread);
 			} else {
 				bool afc = progStatus.afconoff;
@@ -442,13 +438,12 @@ void trx_trx_transmit_loop()
 		bool _txrsid = false;
 		if ( ReedSolomon->assigned(active_modem->get_mode()) && (progdefaults.TransmitRSid || progStatus.n_rsids != 0))
 			_txrsid = true;
-/* Commented out pending development work by KL4YFD
 		else if (ReedSolomon->assigned(active_modem->get_mode()) && 
 				 (active_modem->get_mode() == MODE_OFDM_500F 
 				  || active_modem->get_mode() == MODE_OFDM_750F))
 //				  || active_modem->get_mode() == MODE_OFDM_2000F) )
 			_txrsid = true; // RSID is used as header/preamble for OFDM modes. Make mandatory.
-*/
+			
 		if (_txrsid) {
 			if (progStatus.n_rsids < 0) {
 				for (int i = 0; i > progStatus.n_rsids; i--) {
@@ -702,10 +697,10 @@ static int new_freq;
 
 void trx_start_modem_loop()
 {
-	double save_freq = active_modem->frequency;
+//	double save_freq = active_modem->frequency;
 	if (new_modem == active_modem) {
 		if (new_freq) active_modem->set_freq(new_freq);
-		if (progdefaults.retain_freq_lock) active_modem->tx_frequency = save_freq;
+//		if (progdefaults.retain_freq_lock) active_modem->tx_frequency = save_freq;
 		active_modem->restart();
 		trx_state = STATE_RX;
 		if (progdefaults.show_psm_btn &&
@@ -720,7 +715,7 @@ void trx_start_modem_loop()
 	new_modem->init();
 	active_modem = new_modem;
 	if (new_freq) active_modem->set_freq(new_freq);
-	if (progdefaults.retain_freq_lock) active_modem->tx_frequency = save_freq;
+//	if (progdefaults.retain_freq_lock) active_modem->tx_frequency = save_freq;
 	trx_state = STATE_RX;
 	REQ(update_displays);
 
