@@ -1,22 +1,16 @@
 // ----------------------------------------------------------------------------
 //
+// flxmlrpc Copyright (c) 2015 by W1HKJ, Dave Freese
+//    
 // XmlRpc++ Copyright (c) 2002-2008 by Chris Morley
 //
-// Copyright (C) 2014
-//              David Freese, W1HKJ
-//
 // This file is part of fldigi
 //
-// fldigi is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
+// flxmlrpc is free software; you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
 // the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
-// fldigi is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
@@ -36,6 +30,10 @@
 
 namespace XmlRpc {
 
+  extern std::string pname;
+  
+  extern void set_pname(std::string pn);
+
   // Arguments and results are represented by XmlRpcValues
   class XmlRpcValue;
 
